use actix_identity::Identity;
use actix_web::{web, HttpResponse, Responder};
use askama::Template;
use askama_actix::TemplateToResponse;
use serde::Deserialize;
use sqlx::PgPool;

use crate::models::{Availabillity, Event, Function, Role, User};

#[derive(Deserialize)]
pub struct EventQuery {
    event: i32
}

#[derive(Template)]
#[template(path = "assignment/new.html")]
pub struct NewAssignmentTemplate {
    user: User,
    event: Event,
    available_wachhabende: Vec<Availabillity>,
    available_posten: Vec<Availabillity>,
    all: Vec<Availabillity>
}

#[actix_web::get("/assignments/new")]
pub async fn get(user: Identity, pool: web::Data<PgPool>, query: web::Query<EventQuery>) -> impl Responder {
    let current_user = User::read_by_id(pool.get_ref(), user.id().unwrap().parse().unwrap())
        .await
        .unwrap();

    if let Ok(event) = Event::read_by_id_including_location(pool.get_ref(), query.event).await {
        if current_user.role == Role::Admin || current_user.role == Role::AreaManager && event.location.as_ref().unwrap().area_id == current_user.area_id {
            let all = Availabillity::read_not_assigned_by_date_including_user(pool.get_ref(), event.date).await.unwrap();
            let available_posten = Availabillity::read_not_assigned_by_date_including_user(pool.get_ref(), event.date).await.unwrap();
            let available_wachhabende = available_posten.iter().filter(|a| a.user.as_ref().unwrap().function == Function::Wachhabender).map(|avl| avl.clone()).collect();

            let template = NewAssignmentTemplate { user: current_user, event, available_wachhabende, available_posten, all };

            return template.to_response();
        }

        return HttpResponse::Unauthorized().finish();
    }

    HttpResponse::BadRequest().body("Fehler beim Laden für Assignment")
}
